@@ -48,43 +48,60 @@ test_that("Objective works", {
 
 test_that("Objective specialzations work", {
 
+  FUN_1D_MANY = function(xss) data.table(y = map_dbl(xss, function(xs) as.numeric(xs)^2)) # Many version of FUN_1D in helper.R
+  FUN_2D_MANY = function(xss) data.table(y = map_dbl(xss, function(xs) sum(as.numeric(xs)^2))) # same but FUN_2D
+  FUN_2D_2D_MANY = function(xss) map_dtr(xss, function(xs) data.table(y1 = xs[[1]]^2, y2 = -xs[[2]]^2)) # same as FUN_2D_2D
+  FUN_2D_DEPS_MANY = function(xss) data.table(y = map_dbl(xss, function(xs) sum(as.numeric(xs)^2, na.rm = TRUE)))
+
   FUN_1D_DT = function(xdt) data.table(y = xdt$x^2) # DT version oof FUN_1D in helper.R
   FUN_2D_DT = function(xdt) data.table(y = rowSums(xdt^2)) # same but FUN_2D
   FUN_2D_2D_DT = function(xdt) data.table(y1 = xdt[[1]]^2, y2 = -xdt[[2]]^2) # same as FUN_2D_2D
   FUN_2D_DEPS_DT = function(xdt) data.table(y = rowSums(xdt^2, na.rm = TRUE))
 
+
   # Different function pairs, where the R function uses a different signature but they should do the same
   funs = list(
     list( # 1d x, 1d y
       rfun = ObjectiveRFun$new(fun = FUN_1D, domain = PS_1D, codomain = FUN_1D_CODOMAIN),
-      rfun_dt = ObjectiveRFunDt$new(fun = FUN_1D_DT, domain = PS_1D, codomain = FUN_1D_CODOMAIN)),
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_1D_DT, domain = PS_1D, codomain = FUN_1D_CODOMAIN),
+      rfun_many = ObjectiveRFunMany$new(fun = FUN_1D_MANY, domain = PS_1D, codomain = FUN_1D_CODOMAIN)
+    ),
     list( # 2d x, 1d y
       rfun = ObjectiveRFun$new(fun = FUN_2D, domain = PS_2D),
-      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_DT, domain = PS_2D)
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_DT, domain = PS_2D),
+      rfun_many = ObjectiveRFunMany$new(fun = FUN_2D_MANY, domain = PS_2D)
     ),
     list( # 2d x, 1d y + extra
       rfun = ObjectiveRFun$new(fun = FUN_2D_2D, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN$clone(deep = TRUE)$subset("y1"), id = "function_extras"),
-      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_2D_DT, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN$clone(deep = TRUE)$subset("y1"), , id = "function_extras")
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_2D_DT, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN$clone(deep = TRUE)$subset("y1"), , id = "function_extras"),
+      rfun_many = ObjectiveRFunMany$new(fun = FUN_2D_2D_MANY, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN$clone(deep = TRUE)$subset("y1"), , id = "function_extras")
     ),
     list( # 2d x, 2d y
       rfun = ObjectiveRFun$new(fun = FUN_2D_2D, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN),
-      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_2D_DT, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN)
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_2D_DT, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN),
+      rfun_many = ObjectiveRFunMany$new(fun = FUN_2D_2D_MANY, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN)
     ),
     list( # 2d x with deps, 1d y
       rfun = ObjectiveRFun$new(fun = FUN_2D_DEPS, domain = PS_2D_DEPS, check_values = FALSE), # dont check bc. we get NAs
-      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_DEPS_DT, domain = PS_2D_DEPS, check_values = TRUE) # here NAs can get checked by assert_dt correctly
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_DEPS_DT, domain = PS_2D_DEPS, check_values = TRUE), # here NAs can get checked by assert_dt correctly
+      rfun_many = ObjectiveRFunMany$new(fun = FUN_2D_DEPS_MANY, domain = PS_2D_DEPS, check_values = FALSE)
     )
   )
 
+   fun_pairs = funs[[1]]
+
   for (fun_pairs in funs) {
     fun1 = fun_pairs$rfun
     fun2 = fun_pairs$rfun_dt
+    fun3 = fun_pairs$rfun_many
 
     expect_function(fun1$fun) # check AB
     expect_function(fun2$fun)
+    expect_function(fun3$fun)
 
     expect_output(print(fun1), "ObjectiveRFun:function")
     expect_output(print(fun2), "ObjectiveRFunDt:function")
+    expect_output(print(fun3), "ObjectiveRFunMany:function")
 
     ps = fun1$domain
     sampler = SamplerUnif$new(param_set = ps)
@@ -97,30 +114,39 @@ test_that("Objective specialzations work", {
     expected_colnames = fun1$codomain$ids()
     if ("function_extras" == fun1$id) expected_colnames = c(expected_colnames, "y2")
 
+    # eval_dt
     res1 = fun1$eval_dt(xdt1$data)
     expect_data_table(res1, nrows = 1, ncols = expected_ncols, any.missing = FALSE)
     expect_equal(colnames(res1), expected_colnames)
     expect_equal(res1, fun2$eval_dt(xdt1$data))
+    expect_equal(res1, fun3$eval_dt(xdt1$data))
 
+    # eval
     res2 = fun1$eval(xdt1$transpose()[[1]])
     expect_list(res2)
     expect_equal(names(res2), expected_colnames)
     expect_equal(res2, fun2$eval(xdt1$transpose()[[1]]))
+    expect_equal(res2, fun3$eval(xdt1$transpose()[[1]]))
 
+    # eval_many
     res3 = fun1$eval_many(xdt1$transpose())
     expect_equal(res1, res3)
     expect_equal(res3, fun2$eval_many(xdt1$transpose()))
+    expect_equal(res3, fun3$eval_many(xdt1$transpose()))
 
     # multiple x values in one call
-    xdt3 = sampler$sample(10)
-    res4 = fun1$eval_dt(xdt3$data)
+    xdt2 = sampler$sample(10)
+
+    res4 = fun1$eval_dt(xdt2$data)
     expect_data_table(res4, nrows = 10, ncols = expected_ncols, any.missing = FALSE)
     expect_equal(colnames(res4), expected_colnames)
-    expect_equal(res4, fun2$eval_dt(xdt3$data))
+    expect_equal(res4, fun2$eval_dt(xdt2$data))
+    expect_equal(res4, fun3$eval_dt(xdt2$data))
 
-    res5 = fun1$eval_many(xdt3$transpose())
+    res5 = fun1$eval_many(xdt2$transpose())
     expect_equal(res4, res5)
-    expect_equal(res5, fun2$eval_many(xdt3$transpose()))
+    expect_equal(res5, fun2$eval_many(xdt2$transpose()))
+    expect_equal(res5, fun3$eval_many(xdt2$transpose()))
   }
 })
 
@@ -263,6 +289,16 @@ test_that("ObjectiveRFunDt works with deps #141", {
   xss = design$transpose(trafo = TRUE, filter_na = TRUE)
   res = rfun_dt$eval_many(xss)
   expect_equal(res, data.table(y = c(2, 1)))
+
+  # all configuration miss the same parameter #189
+  design = Design$new(
+    domain,
+    data.table(x1 = 1, x2 = 2),
+    remove_dupl = FALSE
+  )
+  xss = design$transpose(trafo = TRUE, filter_na = TRUE)
+  res = rfun_dt$eval_many(xss)
+  expect_equal(res, data.table(y = 1))
 })
 
 test_that("Objective works with constants", {
