@@ -18,8 +18,6 @@ test_that("status method works", {
   Sys.sleep(1)
 
   expect_equal(inst$terminator$status(inst$archive)["max_steps"], c("max_steps" = 3))
-  expect_equal(inst$terminator$status(inst$archive)["current_steps"], c("current_steps" = 1), tolerance = 1)
-  expect_equal(inst$terminator$remaining_time(inst$archive), 2, tolerance = 1)
 })
 
 test_that("TerminatorClockTime works with empty archive", {
@@ -28,3 +26,8 @@ test_that("TerminatorClockTime works with empty archive", {
   archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
 })
+
+test_that("man exists", {
+  terminator = trm("clock_time")
+  expect_man_exists(terminator$man)
+})
